#
# spec file for package drumstick
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2005-2010 Pedro Lopez-Cabanillas <plcl@users.sourceforge.net>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           drumstick
Version:        2.5.0
Release:        bp154.1.59
Summary:        MIDI Sequencer C++ Library Bindings
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://drumstick.sourceforge.io/
Source:         https://sourceforge.net/projects/drumstick/files/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5UiPlugin)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(alsa)
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
BuildRequires:  pkgconfig(fluidsynth)
%endif
BuildRequires:  pkgconfig(libpulse-simple)

%description
This package includes test and example programs for drumstick libraries.

%lang_package

%package mimetypes
Summary:        MIDI Sequencer C++ Library MIME types
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
Conflicts:      libdrumstick-file1

%description mimetypes
This package includes a mimetype for Cakewalk project files.

%package -n libdrumstick-rt2
Summary:        MIDI Sequencer C++ Library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/Libraries
Requires:       libdrumstick-rt2-plugins

%description -n libdrumstick-rt2
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes a class for managing realtime MIDI input/output backends.

%package -n libdrumstick-rt2-plugins
Summary:        MIDI Sequencer C++ Library
License:        Apache-2.0 AND GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/Libraries

%description -n libdrumstick-rt2-plugins
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This package contains input/output plugins for libdrumstick-rt2.

%package -n libdrumstick-file2
Summary:        MIDI Sequencer C++ Library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/Libraries
Recommends:     %{name}-mimetypes

%description -n libdrumstick-file2
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes classes providing file input and output in formats
commonly used by MIDI programs. Currently, SMF (standard MIDI file)
read/write and WRK (Cakewalk) file read are supported. This library does not
depend on ALSA.

%package -n libdrumstick-alsa2
Summary:        MIDI Sequencer C++ Library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/Libraries

%description -n libdrumstick-alsa2
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes the ALSA Sequencer library classes, providing MIDI
recording and playback functionality to C++/Qt5 programs.

%package -n libdrumstick-widgets2
Summary:        MIDI Sequencer C++ Library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/Libraries
# for the lang_package
Provides:       libdrumstick-widgets = %{version}

%description -n libdrumstick-widgets2
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes the Widgets library, providing
GUI, MIDI related, components for C++/Qt5 programs.

%lang_package -n libdrumstick-widgets

%package -n libdrumstick-devel
Summary:        Development package for the libdrumstick library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       alsa-devel
Requires:       glibc-devel
Requires:       libdrumstick-alsa2 = %{version}
Requires:       libdrumstick-file2 = %{version}
Requires:       libdrumstick-rt2 = %{version}
Requires:       libdrumstick-widgets2 = %{version}
Requires:       libstdc++-devel
Requires:       cmake(Qt5Core)

%description -n libdrumstick-devel
This package contains the files needed to compile programs that use the
libdrumstick libraries.

%package -n libdrumstick-doc
Summary:        Development documentation package for the drumstick libraries
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Documentation/Other
BuildArch:      noarch

%description -n libdrumstick-doc
This package contains the developer's documentation of the drumstick libraries.

%prep
%setup -q

# Update obsolete config file
doxygen -u Doxyfile.in
sed -i 's#%{_includedir}/QtCore#%{_includedir}/qt5/QtCore#' Doxyfile.in
sed -i 's#%{_includedir}/QtGui#%{_includedir}/qt5/QtGui#' Doxyfile.in

%build
%cmake -DSTATIC_DRUMSTICK=0 -DCMAKE_INSTALL_LIBDIR=%{_lib}
%cmake_build
make %{?_smp_mflags} doxygen

%install
%cmake_install
%suse_update_desktop_file -n drumstick-drumgrid Midi
%suse_update_desktop_file -n drumstick-guiplayer Midi
%suse_update_desktop_file -n drumstick-vpiano Midi

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post -n libdrumstick-file2 -p /sbin/ldconfig
%postun -n libdrumstick-file2 -p /sbin/ldconfig
%post -n libdrumstick-alsa2 -p /sbin/ldconfig
%postun -n libdrumstick-alsa2 -p /sbin/ldconfig
%post -n libdrumstick-rt2 -p /sbin/ldconfig
%postun -n libdrumstick-rt2 -p /sbin/ldconfig
%post -n libdrumstick-widgets2 -p /sbin/ldconfig
%postun -n libdrumstick-widgets2 -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS NEWS TODO ChangeLog
%{_bindir}/%{name}-*
%{_datadir}/applications/%{name}-*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svgz
%{_mandir}/man1/%{name}-*.1%{?ext_man}

%files lang
%license COPYING
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/drumstick-drumgrid_*.qm
%{_datadir}/%{name}/drumstick-guiplayer_*.qm
%{_datadir}/%{name}/drumstick-vpiano_*.qm

%files mimetypes
%{_datadir}/mime/packages/%{name}.xml

%files -n libdrumstick-rt2
%license COPYING
%{_libdir}/libdrumstick-rt.so.*

%files -n libdrumstick-rt2-plugins
%license COPYING
%{_libdir}/drumstick2/

%files -n libdrumstick-file2
%license COPYING
%{_libdir}/libdrumstick-file.so.*

%files -n libdrumstick-alsa2
%license COPYING
%{_libdir}/libdrumstick-alsa.so.*

%files -n libdrumstick-widgets2
%license COPYING
%{_libdir}/libdrumstick-widgets.so.*

%files -n libdrumstick-widgets-lang
%license COPYING
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/drumstick-widgets_*.qm

%files -n libdrumstick-devel
%license COPYING
%dir %{_includedir}/%{name}
%dir %{_libqt5_plugindir}/designer
%{_includedir}/%{name}.h
%{_includedir}/%{name}/*.h
%{_libdir}/libdrumstick-alsa.so
%{_libdir}/libdrumstick-file.so
%{_libdir}/libdrumstick-rt.so
%{_libdir}/libdrumstick-widgets.so
%{_libdir}/pkgconfig/%{name}-*.pc
%{_libdir}/cmake/%{name}
%{_libqt5_plugindir}/designer/libdrumstick-vpiano-plugin.so

%files -n libdrumstick-doc
%doc build/doc/html/*

%changelog
* Tue Jan 25 2022 Wolfgang Bauer <wbauer@tmo.at>
- Enable fluidsynth support on Leap 15.4 too, fluidsynth was
  updated
* Mon Jan  3 2022 Giordano Boschetti <geekosdaw@gmail.com>
- Update to 2.5.0
  * Documentation/deprecation of Drumstick::File functions affected by QTextCodec
  * Documented new build options and Qt6Core5Compat dependency for Drumstick::File
  * Raised macOS deployment target to 10.13 (High Sierra)
  * RT, VPiano: Fixed ALSA backend, enable empty input connection.
  * New build options: BUILD_ALSA, BUILD_FILE, BUILD_RT, BUILD_WIDGETS
  * Reduced usage of Qt6Core5Compat to the minimum
  * Widgets: changed the white keys background picture depending on the key background color
  * VPiano: new option to display inverted key colors
  * fix for ticket #37: WRK format markers are not decoded
  * Widgets library Swedish translation updated. Thanks to Magnus Johansson.
  * Widgets library Czech translation updated. Thanks to Pavel Fric.
* Wed Oct  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.4.0
  * RIFF RMID file support. New utility dumprmi, and guiplayer updated.
  * Fixed missing library version functions in File and RT libs
  * Enabled by default the internal reverb on macOS DLS Synth
  * Avoid hardcoded font family name in vpiano
* Wed Aug 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.3.1
  * updated documentation
  * Fixed WRK file processing in guiplayer utility
  * Fixed SMF system exclusive event write method
* Wed Jun 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.3.0. Changes since 2.2.0:
  * experimental cmake support for building with Qt6
  * New options: USE_PULSEAUDIO, USE_FLUIDSYNTH, USE_NETWORK
  * Revised CMake buildsystem and documents
  * Widgets: Fixed touch events - checked pressure capability
* Thu May 20 2021 Wolfgang Bauer <wbauer@tmo.at>
- Build without fluidsynth on Leap 15, the included one is too old
* Sat May 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.2.0
  * New option BUILD_UTILS
  * FluidSynth backend: initialization moved to a background thread
  * Retrieve dynamically the audio driver names for using in
    configuration dialog
  * new QWrk class signals with a QByteArray parameter
    instead of QString
  * Standarization: MIDI texts/lyrics encoding defaults to Latin1
  * removed warnings when buiding with Qt >= 5.15
  * * French and German translations updated
* Thu Apr 22 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.1.1. Fixes:
  * highlight color is wrong unless velocity tint is active
  * error parsing a wrk file
  * fixed stop playback, removed Overture mimetype from desktop
    file
  See the installed ChangeLog file for other changes.
* Tue Jan 12 2021 Wolfgang Bauer <wbauer@tmo.at>
- Split out the Cakewalk mimetype into a seperate package, it
  breaks co-installability of several library versions
* Sun Jan 10 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 2.0.0
  * New features:
    + Code and build systems modernization
    + Namespaces reorganization
    + New library: drumstick-widgets providing a PianoKeybd widget
    plugin for Qt Creator and Qt Designer
    + New unit tests, for drumstick-widgets and wrk files
    + translations for drumstick-widgets and utils
    + License GPLv3 for all components
    + Each library provides at runtime its version in string format
    + Every program reports the linked library names/versions in
    the about box
    + Documentation of the new API for drumstick-widgets
    + drumstick-rt: plugins versioning, allowing runtime
    coexistence between plugins of drumstick-1 and drumstick-2.
  * Fixes:
    + drumstick-file: OVE file support removal
    + New library drumstick-widgets
    + Same names for ALSA Sequencer clients of two hw USB
    controllers
    + regression: drumstick-guiplayer doesn't remember saved MIDI
    output device
    + Better rendering of note names in piano keyboard widget
    + drumstick-vpiano: fixed SonivoxEAS saved connection string
- Use %%cmake instead of %%cmake_kf5 and remove kf5-filesystem
  BuildRequires, the package doesn't use KDE Frameworks at all
* Sun Oct 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.1.3
  * IPv6 support added
  * Avoid endless loops on unexpected end of input.
  * Generate SMFError when the parser finds unexpected end of input.
  * general cleanups and bringing back the fluidsynth backend
  * migration to full GNUInstallDirs support
  * modernization started of the CMake build system
  * Library includes reorganization
  * Fixed drumstick-file unit test
  * Custom commandline parser replaced by standard Qt5 QCommandLineParser
  * fixed spurious error message for ALSA input
- Drop Dont-use-QOverload.patch. No longer needed.
- Update the libdrumstick-rt-plugins license tag, eassynth contains
  Apache-2.0 files.
* Tue Dec 18 2018 wbauer@tmo.at
- Add Dont-use-QOverload.patch to make it build on Leap 42.3
* Tue Dec 18 2018 wbauer@tmo.at
- Update to 1.1.2
  * Fix for ticket #13 - some macOS input events lost
  * Added some bundle metadata for macOS
  * Solution for ticket #8: Path for plugins hardcoded
- Add pkgconfig(libpulse-simple) BuildRequires to enable building
  of libdrumstick-rt-eassynth.so (boo#1119734)
- Move rt input/output plugins to a separate
  libdrumstick-rt-plugins package that's required by
  libdrumstick-rt1
* Fri May 25 2018 christophe@krop.fr
- Update to 1.1.1
  * fixed tab order on forms
  * rt: fixed pitch bend events on several output backends
  * removed ALSA/Linux dependency where possible.
  * disabled fluidsynth output driver
- Split libdrumstick-rt from the main package.
* Mon Dec 18 2017 christophe@krop.fr
- Update to 1.1.0
  * guiplayer accepts a single file argument in the command line:
    mid, kar, wrk and ove
  * documentation updated
  Check the installed ChangeLog file for the complete changelog.
- Drop gcc6-fix.patch. Merged upstream.
* Fri Jun 17 2016 jengelh@inai.de
- Drop archaic sections, set rpm groups
* Fri Jun 17 2016 wbauer@tmo.at
- The devel package requires libQt5Core-devel now, not libqt4-devel
* Fri Jun 17 2016 wbauer@tmo.at
- Add gcc6-fix.patch to fix build with gcc6
* Wed Jun 15 2016 wbauer@tmo.at
- Use shared-mime-database macros (boo#979301)
* Tue Apr 12 2016 tittiatcoke@gmail.com
- Update to version 1.0.2
  * Qt5 port.
- Drop x11.diff. No longer required.
* Sun Nov 13 2011 alinm.elena@gmail.com
- fixed x11 failure to link in 12.1 added x11.diff patch
- moved to cmake_kde4 macro
* Thu Feb 17 2011 javier@opensuse.org
- switch to %%{?_smp_mflags}, remove additional optflags,
  clean package file list
* Wed Feb 16 2011 javier@opensuse.org
- fix package file list
* Wed Feb 16 2011 javier@opensuse.org
- copy package from home:plcl and clean spec a bit
